@@ -5,3 +5,7 @@ mlr3misc::clbk
 #' @importFrom mlr3misc clbks
 #' @export
 mlr3misc::clbks
+
+#' @importFrom mlr3misc mlr_callbacks
+#' @export
+mlr3misc::mlr_callbacks
