@@ -1,3 +1,23 @@
+#' @importFrom mlr3tuning auto_tuner
+#' @export
+mlr3tuning::auto_tuner
+
+#' @importFrom mlr3tuning callback_async_tuning
+#' @export
+mlr3tuning::callback_async_tuning
+
+#' @importFrom mlr3tuning callback_batch_tuning
+#' @export
+mlr3tuning::callback_batch_tuning
+
+#' @importFrom mlr3tuning extract_inner_tuning_results
+#' @export
+mlr3tuning::extract_inner_tuning_results
+
+#' @importFrom mlr3tuning extract_inner_tuning_archives
+#' @export
+mlr3tuning::extract_inner_tuning_archives
+
 #' @importFrom mlr3tuning mlr_tuners
 #' @export
 mlr3tuning::mlr_tuners
@@ -10,38 +30,18 @@ mlr3tuning::tnr
 #' @export
 mlr3tuning::tnrs
 
-#' @importFrom mlr3tuning AutoTuner
+#' @importFrom mlr3tuning ti
 #' @export
-mlr3tuning::AutoTuner
+mlr3tuning::ti
 
-#' @importFrom mlr3tuning TuningInstanceSingleCrit
+#' @importFrom mlr3tuning ti_async
 #' @export
-mlr3tuning::TuningInstanceSingleCrit
-
-#' @importFrom mlr3tuning TuningInstanceMultiCrit
-#' @export
-mlr3tuning::TuningInstanceMultiCrit
-
-#' @importFrom mlr3tuning extract_inner_tuning_results
-#' @export
-mlr3tuning::extract_inner_tuning_results
-
-#' @importFrom mlr3tuning extract_inner_tuning_archives
-#' @export
-mlr3tuning::extract_inner_tuning_archives
-
-#' @importFrom mlr3tuning tune
-#' @export
-mlr3tuning::tune
+mlr3tuning::ti_async
 
 #' @importFrom mlr3tuning tune_nested
 #' @export
 mlr3tuning::tune_nested
 
-#' @importFrom mlr3tuning auto_tuner
+#' @importFrom mlr3tuning tune
 #' @export
-mlr3tuning::auto_tuner
-
-#' @importFrom mlr3tuning ti
-#' @export
-mlr3tuning::ti
+mlr3tuning::tune
